@@ -12,10 +12,13 @@ bool find_chessboard_corners_from_image_array_C( // in
                                                 int stride,
                                                 char* imagebuffer, // this is const
 
-                                                // set to 0 to just use the image
+                                                // set to 0 to just use the image. Set
+                                                // to <0 to try automatically find a
+                                                // good scaling level. Try this first
                                                 int image_pyramid_level,
+                                                bool doblobs,
 
-                                                bool (*add_pointss)(int* xy, int N, double scale) );
+                                                bool (*add_points)(int* xy, int N, double scale) );
 
 bool find_chessboard_from_image_array_C( // in
                                         int Nrows, int Ncols,
@@ -28,6 +31,7 @@ bool find_chessboard_from_image_array_C( // in
                                         // to <0 to try automatically find a
                                         // good scaling level. Try this first
                                         int image_pyramid_level,
+                                        bool doblobs,
 
                                         bool (*add_points)(double* xy, int N) );
 #ifdef __cplusplus
